Computer class

Contains information about a computer account in a directory.

Constructors

Computer({List<Attribute>? computerAttributes, String? computerId, String? computerName})
Computer.fromJson(Map<String, dynamic> json)
factory

Properties

computerAttributes → List<Attribute>?
An array of Attribute objects containing the LDAP attributes that belong to the computer account.
final
computerId → String?
The identifier of the computer.
final
computerName → String?
The computer name.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited