CreateAliasResult class

Contains the results of the CreateAlias operation.

Constructors

CreateAliasResult({String? alias, String? directoryId})
CreateAliasResult.fromJson(Map<String, dynamic> json)
factory

Properties

alias → String?
The alias for the directory.
final
directoryId → String?
The identifier of the directory.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited