DescribeDomainControllersResult class

Constructors

DescribeDomainControllersResult({List<DomainController>? domainControllers, String? nextToken})
DescribeDomainControllersResult.fromJson(Map<String, dynamic> json)
factory

Properties

domainControllers → List<DomainController>?
List of the DomainController objects that were retrieved.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If not null, more results are available. Pass this value for the NextToken parameter in a subsequent call to DescribeDomainControllers retrieve the next set of items.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited