DomainController class

Contains information about the domain controllers for a specified directory.

Constructors

DomainController({String? availabilityZone, String? directoryId, String? dnsIpAddr, String? domainControllerId, DateTime? launchTime, DomainControllerStatus? status, DateTime? statusLastUpdatedDateTime, String? statusReason, String? subnetId, String? vpcId})
DomainController.fromJson(Map<String, dynamic> json)
factory

Properties

availabilityZone → String?
The Availability Zone where the domain controller is located.
final
directoryId → String?
Identifier of the directory where the domain controller resides.
final
dnsIpAddr → String?
The IP address of the domain controller.
final
domainControllerId → String?
Identifies a specific domain controller in the directory.
final
hashCode → int
The hash code for this object.
no setterinherited
launchTime → DateTime?
Specifies when the domain controller was created.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DomainControllerStatus?
The status of the domain controller.
final
statusLastUpdatedDateTime → DateTime?
The date and time that the status was last updated.
final
statusReason → String?
A description of the domain controller state.
final
subnetId → String?
Identifier of the subnet in the VPC that contains the domain controller.
final
vpcId → String?
The identifier of the VPC that contains the domain controller.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited