EventTopic class

Information about SNS topic and AWS Directory Service directory associations.

Constructors

EventTopic({DateTime? createdDateTime, String? directoryId, TopicStatus? status, String? topicArn, String? topicName})
EventTopic.fromJson(Map<String, dynamic> json)
factory

Properties

createdDateTime → DateTime?
The date and time of when you associated your directory with the SNS topic.
final
directoryId → String?
The Directory ID of an AWS Directory Service directory that will publish status messages to an SNS topic.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TopicStatus?
The topic registration status.
final
topicArn → String?
The SNS topic ARN (Amazon Resource Name).
final
topicName → String?
The name of an AWS SNS topic the receives status messages from the directory.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited