LogSubscription class

Represents a log subscription, which tracks real-time data from a chosen log group to a specified destination.

Constructors

LogSubscription({String? directoryId, String? logGroupName, DateTime? subscriptionCreatedDateTime})
LogSubscription.fromJson(Map<String, dynamic> json)
factory

Properties

directoryId → String?
Identifier (ID) of the directory that you want to associate with the log subscription.
final
hashCode → int
The hash code for this object.
no setterinherited
logGroupName → String?
The name of the log group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionCreatedDateTime → DateTime?
The date and time that the log subscription was created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited