SharedDirectory class

Details about the shared directory in the directory owner account for which the share request in the directory consumer account has been accepted.

Constructors

SharedDirectory({DateTime? createdDateTime, DateTime? lastUpdatedDateTime, String? ownerAccountId, String? ownerDirectoryId, ShareMethod? shareMethod, String? shareNotes, ShareStatus? shareStatus, String? sharedAccountId, String? sharedDirectoryId})
SharedDirectory.fromJson(Map<String, dynamic> json)
factory

Properties

createdDateTime → DateTime?
The date and time that the shared directory was created.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedDateTime → DateTime?
The date and time that the shared directory was last updated.
final
ownerAccountId → String?
Identifier of the directory owner account, which contains the directory that has been shared to the consumer account.
final
ownerDirectoryId → String?
Identifier of the directory in the directory owner account.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedAccountId → String?
Identifier of the directory consumer account that has access to the shared directory (OwnerDirectoryId) in the directory owner account.
final
sharedDirectoryId → String?
Identifier of the shared directory in the directory consumer account. This identifier is different for each directory owner account.
final
shareMethod → ShareMethod?
The method used when sharing a directory to determine whether the directory should be shared within your AWS organization (ORGANIZATIONS) or with any AWS account by sending a shared directory request (HANDSHAKE).
final
shareNotes → String?
A directory share request that is sent by the directory owner to the directory consumer. The request includes a typed message to help the directory consumer administrator determine whether to approve or reject the share invitation.
final
shareStatus → ShareStatus?
Current directory status of the shared AWS Managed Microsoft AD directory.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited