Tag class

Metadata assigned to a directory consisting of a key-value pair.

Constructors

Tag({required String key, required String value})
Tag.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
Required name of the tag. The string value can be Unicode characters and cannot be prefixed with "aws:". The string can contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: "^(\p{L}\p{Z}\p{N}_.:/=+\-*)$").
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The optional value of the tag. The string value can be Unicode characters. The string can contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: "^(\p{L}\p{Z}\p{N}_.:/=+\-*)$").
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited